@@ -23,9 +23,9 @@
 #define XFCE4_CPUFREQ_H
 
 #include <gtk/gtk.h>
-#include <libxfce4panel/xfce-panel-plugin.h>
+#include <libxfce4panel/libxfce4panel.h>
 
-#define PLUGIN_WEBSITE ("http://goodies.xfce.org/projects/panel-plugins/xfce4-cpufreq-plugin")
+#define PLUGIN_WEBSITE ("https://docs.xfce.org/panel-plugins/xfce4-cpufreq-plugin")
 
 #define CPU_MIN (cpuFreq->cpus->len + 0)
 #define CPU_AVG (cpuFreq->cpus->len + 1)
@@ -93,7 +93,7 @@ typedef struct
   gint timeoutHandle;
 } CpuFreqPlugin;
 
-CpuFreqPlugin *cpuFreq;
+extern CpuFreqPlugin *cpuFreq;
 
 G_BEGIN_DECLS
 
